Perso-Arabic Script Code for Information Interchange - Wikipedia

# Perso-Arabic Script Code for Information Interchange

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

Perso-Arabic Script Code for Information Interchange (PASCII) is one of the Indian government standards for encoding languages using writing systems based on Perso-Arabic alphabet, in particular Kashmiri, Persian, Sindhi and Urdu. The ISCII encoding was originally intended to cover both the Brahmi-derived writing systems of India and the Arabic-based systems, but it was subsequently decided to encode the Arabic-based writing systems separately.

PASCII has not been widely used outside certain government institutions and has now been rendered largely obsolete by Unicode. Unicode uses a separate block for each writing system and largely preserves the PASCII layout within each block.

## Codepage layout[edit]

The following table shows the character set for PASCII. Each character is shown with its decimal code and its Unicode equivalent.

PASCII
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 | NUL 0000 | SOH 0001 | STX 0002 | ETX 0003 | EOT 0004 | ENQ 0005 | ACK 0006 | BEL 0007 | BS 0008 | HT 0009 | LF 000A | VT 000B | FF 000C | CR 000D | SO 000E | SI 000F
1_ 16 | DLE 0010 | DC1 0011 | DC2 0012 | DC3 0013 | DC4 0014 | NAK 0015 | SYN 0016 | ETB 0017 | CAN 0018 | EM 0019 | SUB 001A | ESC 001B | FS 001C | GS 001D | RS 001E | US 001F
2_ 32 | SP 0020 | ! 0021 | " 0022 | # 0023 | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ 48 | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ 64 | @ 0040 | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ 80 | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B | \ 005C | ] 005D | ^ 005E | _ 005F
6_ 96 | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ 112 | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B | | 007C | } 007D | ~ 007E | DEL 007F
8_ 128 |  | ـ 0640 | ا 0627 | آ 0622 | ب 0628 | ٻ 067B | ڀ 0680 | پ 067E | ڦ 06A6 | ت 062A | ة 0629 | ٿ 067F | ٹ[a] 0679 | ٺ 067A | ث 062B | ج 062C
9_ 144 | ڄ 0684 | ڃ 0683 | چ 0686 | ڇ 0687 | ح 062D | خ 062E | د 062F | ڌ 068C | ڈ[b] 0688 | ڏ 068F | ڍ 068D | ذ 0630 | ر 0631 | ڑ[c] 0691 | ڙﻬ 0699/FEEC | ز 0632
A_ 160 | ژ 0698 | س 0633 | ش 0634 | ص 0635 | ض 0636 | ط 0637 | ظ 0638 | ع 0639 | غ 063A | ف 0641 | ق 0642 | ڪ[d] 06AA | ک 06A9 | گ 06AF | ڳ 06B3 | ڱ 06B1
B_ 176 | ل 0644 | م 0645 | ن 0646 | ں 06BA | ڻ 06BB | و 0648 | ۄ 06C4 | ه 0647 | ھ 06BE | ء 0621 | ى 0649 | ؠ 0620 | ۓ 06D3 | ے 06D2 | َ 064E | ِ 0650
C_ 192 | ُ 064F | ٗ 0657 | ٔ 0654 | ٕ 0655 | ٔ[e] 0654 | ٟ 065F | ّ 0651 | ٓ 0653 | ۡ 06E1 | ٰ 0670 | ٖ 0656 | [f] | …[g] 2026 | ؔ 0614 | ، 060C | ؐ 0610
D_ 208 | ؓ 0613 | ؒ 0612 | ؑ 0611 | ࣗ 08D7 | [h] | ۙ 06D9 | ۚ 06DA | ۢ 06E2 | ؁[g] 0601 | ٪ 066A | ٬ 066C | ٫ 066B | ۰ 06F0 | ۱ 06F1 | ۲ 06F2 | ۳ 06F3
E_ 224 | ۴ 06F4 | ۵ 06F5 | ۶ 06F6 | ۷ 06F7 | ۸ 06F8 | ۹ 06F9 | ! 0021 | “ 201C | ” 201D | ‘ 2018 | ’ 2019 | ( 0028 | ) 0029 | ٭ 066D | + 002B | ATR
F_ 240 | - 002D | / 002F | ؛ 061B | : 003A | ؟ 061F | = 003D | ۔ 06D4 | ۝ 06DD | ●[g] 25CF | ٬ 066C | DM | LB | ◌[g] 25CC | · 00B7 |  |

Letter Number Punctuation Symbol Other Undefined

1. ^ This character is displayed as ٽ (Unicode point 067D) for Sindhi texts.
2. ^ This character is displayed as ڊ (Unicode point 068A) for Sindhi texts.
3. ^ This character is displayed as ڙ (Unicode point 0699) for Sindhi texts.
4. ^ This character is usually displayed as ک (Unicode point 06A9) in non-Sindhi texts. See also: Khē
5. ^ This code space is used for Kashmiri hamza, an orthographic variation not used in Unicode. This diacritic on an alif is 0672 in Unicode.
6. ^ This diacritic currently has no Unicode support. This diacritic on an alif is 0671 in Unicode.
7. ^ a b c d This punctuation mark currently has no Unicode support. Nearest equivalent shown.
8. ^ This combining superscript letter kaf currently has no Unicode support.

## References[edit]

- PASCII at Center for Development of Advanced Computing

Retrieved from "https://en.wikipedia.org/w/index.php?title=Perso-Arabic_Script_Code_for_Information_Interchange&oldid=1006726234"
Categories:

- Character encoding
- Character sets